==> haskell-network-ip-0.3-12-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-network-ip.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: network-ip
version: 0.3
id: network-ip-0.3-DGK787RDFix1qeevScFPS1
key: network-ip-0.3-DGK787RDFix1qeevScFPS1
license: BSD3
copyright: 2011-2016 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/network-ip
synopsis: Internet Protocol data structures
description:
    This package provides Internet Protocol data structures
category: Network
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
exposed: True
exposed-modules:
    Network.IP.Addr
abi: 5deb763abe5ac6364f24d8d68765ba4e
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/network-ip-0.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/network-ip-0.3
data-dir: /usr/share/arm-linux-ghc-8.0.1/network-ip-0.3
hs-libraries: HSnetwork-ip-0.3-DGK787RDFix1qeevScFPS1
depends:
    base-4.9.0.0 data-default-class-0.1.2.0-6eetmQ6CbQOLoXb6k5kODu
    data-dword-0.3.1.1-8FidQK8SjvS1MBD4nE2pUO
    data-endian-0.1.1-8uxPbJpGjmuKDaF1nxHF2h
    data-serializer-0.3-AMlggBQrNzfxItkoU9wJK
    data-textual-0.3.0.2-LM1v8K05tqNJjzqVOo9CGn
    hashable-1.2.6.0-CKFo6Z8S7bXH0jokyKXcu0
    parsers-0.12.5-7T5JgQNHyxUIEz7YU7oet0
    text-printer-0.5-LEBVCr4dyYi1RN0kjLDrdn
    type-hint-0.1-B9kQ3N6jTx1B7uQG3ft6E4
haddock-interfaces: /usr/share/doc/haskell-network-ip/html/network-ip.haddock
haddock-html: /usr/share/doc/haskell-network-ip/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-ip-0.3-13-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-network-ip.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: network-ip
version: 0.3
id: network-ip-0.3-5GQDzVQ4kG5Aub5t14Fq1Z
key: network-ip-0.3-5GQDzVQ4kG5Aub5t14Fq1Z
license: BSD3
copyright: 2011-2016 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/network-ip
synopsis: Internet Protocol data structures
description:
    This package provides Internet Protocol data structures
category: Network
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
exposed: True
exposed-modules:
    Network.IP.Addr
abi: ffeea6eb56024f9871dd143ce709d75d
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/network-ip-0.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/network-ip-0.3
data-dir: /usr/share/arm-linux-ghc-8.0.1/network-ip-0.3
hs-libraries: HSnetwork-ip-0.3-5GQDzVQ4kG5Aub5t14Fq1Z
depends:
    base-4.9.0.0 data-default-class-0.1.2.0-6eetmQ6CbQOLoXb6k5kODu
    data-dword-0.3.1.1-8FidQK8SjvS1MBD4nE2pUO
    data-endian-0.1.1-8uxPbJpGjmuKDaF1nxHF2h
    data-serializer-0.3-HBFBIRzMnadGGGA1Xx0QOH
    data-textual-0.3.0.2-6qbc0JHf7YEGDCrzxc5tj9
    hashable-1.2.6.0-CKFo6Z8S7bXH0jokyKXcu0
    parsers-0.12.5-AF1D0MdDjKYIjCNPomIGL6
    text-printer-0.5-LEBVCr4dyYi1RN0kjLDrdn
    type-hint-0.1-B9kQ3N6jTx1B7uQG3ft6E4
haddock-interfaces: /usr/share/doc/haskell-network-ip/html/network-ip.haddock
haddock-html: /usr/share/doc/haskell-network-ip/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
